pdfHyperlinkDialogOpenLabel property
Label that is displayed in the hyperlink dialog of PdfViewer to represent the OPEN confirmation button.
Implementation
String get pdfHyperlinkDialogOpenLabel;
Label that is displayed in the hyperlink dialog of PdfViewer to represent the OPEN confirmation button.
String get pdfHyperlinkDialogOpenLabel;