pdfTextSelectionMenuSquigglyLabel property
String
get
pdfTextSelectionMenuSquigglyLabel
override
Label that is displayed in the text selection context menu of
PdfViewer for underlining the selected text with squiggly style.
Implementation
@override
String get pdfTextSelectionMenuSquigglyLabel => r'波浪線';